(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[5181],{38346:function(n,t,e){"use strict";e.d(t,{D:function(){return r}});var r=function(n,t){var e,r=arguments.length>2&&void 0!==arguments[2]&&arguments[2];return function(){for(var u=arguments.length,i=new Array(u),o=0;o<u;o++)i[o]=arguments[o];var a=this,s=function(){e=null,r||n.apply(a,i)},c=r&&!e;clearTimeout(e),e=setTimeout(s,t),c&&n.apply(a,i)}}},62359:function(n,t,e){"use strict";e.d(t,{j:function(){return u}});var r=e(47181),u=function(n){(0,r.B)(window,"haptic",n)}}}]);
//# sourceMappingURL=chunk.c79cdf4912347927d510.js.map