(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[651],{70651:function(n,e,t){"use strict";function i(){var n=function(n,e){e||(e=n.slice(0));return Object.freeze(Object.defineProperties(n,{raw:{value:Object.freeze(e)}}))}(['\n  #sortable a:nth-of-type(2n) paper-icon-item {\n    animation-name: keyframes1;\n    animation-iteration-count: infinite;\n    transform-origin: 50% 10%;\n    animation-delay: -0.75s;\n    animation-duration: 0.25s;\n  }\n\n  #sortable a:nth-of-type(2n-1) paper-icon-item {\n    animation-name: keyframes2;\n    animation-iteration-count: infinite;\n    animation-direction: alternate;\n    transform-origin: 30% 5%;\n    animation-delay: -0.5s;\n    animation-duration: 0.33s;\n  }\n\n  #sortable a {\n    height: 48px;\n    display: flex;\n  }\n\n  #sortable {\n    outline: none;\n    display: block !important;\n  }\n\n  .hidden-panel {\n    display: flex !important;\n  }\n\n  .sortable-fallback {\n    display: none;\n  }\n\n  .sortable-ghost {\n    opacity: 0.4;\n  }\n\n  .sortable-fallback {\n    opacity: 0;\n  }\n\n  @keyframes keyframes1 {\n    0% {\n      transform: rotate(-1deg);\n      animation-timing-function: ease-in;\n    }\n\n    50% {\n      transform: rotate(1.5deg);\n      animation-timing-function: ease-out;\n    }\n  }\n\n  @keyframes keyframes2 {\n    0% {\n      transform: rotate(1deg);\n      animation-timing-function: ease-in;\n    }\n\n    50% {\n      transform: rotate(-1.5deg);\n      animation-timing-function: ease-out;\n    }\n  }\n\n  .show-panel,\n  .hide-panel {\n    display: none;\n    position: absolute;\n    top: 0;\n    right: 4px;\n    --mdc-icon-button-size: 40px;\n  }\n\n  :host([rtl]) .show-panel {\n    right: initial;\n    left: 4px;\n  }\n\n  .hide-panel {\n    top: 4px;\n    right: 8px;\n  }\n\n  :host([rtl]) .hide-panel {\n    right: initial;\n    left: 8px;\n  }\n\n  :host([expanded]) .hide-panel {\n    display: block;\n  }\n\n  :host([expanded]) .show-panel {\n    display: inline-flex;\n  }\n\n  paper-icon-item.hidden-panel,\n  paper-icon-item.hidden-panel span,\n  paper-icon-item.hidden-panel ha-icon[slot="item-icon"] {\n    color: var(--secondary-text-color);\n    cursor: pointer;\n  }\n']);return i=function(){return n},n}t.r(e),t.d(e,{sortableStyles:function(){return a}});var a=(0,t(15652).iv)(i())}}]);
//# sourceMappingURL=chunk.c72c3c0a027587c975e7.js.map