@keyframes play126 {
  0% {
    background-position: 0px 0px;
  }
  100% {
    background-position: -26460px 0px;
  }
}
.shapeshifter {
  animation-duration: 2100ms;
  animation-timing-function: steps(126);
  width: 100%;
  height: 0px;
  background-repeat: no-repeat;
  animation-iteration-count: infinite;
}
.shapeshifter.play {
  animation-name: play126;
}

body {
  background: #fff;
  font-family: sans-serif;
}

div.center {
  position: absolute;
  left: 50%;
  top: 50%;
  -webkit-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  text-align: center;
  width: 100%;
}

div.aisdom {
  font-weight: bold;
  font-size: 16vw;
}

@keyframes blink {
  0% {
    opacity: 0.2;
  }
  20% {
    opacity: 1;
  }
  100% {
    opacity: 0.2;
  }
}

p.loading {
  font-size: 8vw;
  margin: 5px;
}
.loading span {
  animation-name: blink;
  animation-duration: 1.4s;
  animation-iteration-count: infinite;
  animation-fill-mode: both;
}

.loading span:nth-child(2) {
  animation-delay: 0.2s;
}

.loading span:nth-child(3) {
  animation-delay: 0.4s;
}

footer {
  width: 100%;
}
