(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[9017],{89017:(e,s,l)=>{"use strict";l.r(s);var t=l(50856),a=l(28426);class r extends a.H3{static get template(){return t.d`
      <style include="ha-style">
        iframe {
          border: 0;
          width: 100%;
          height: 100%;
        }
      </style>
      <iframe
        src="//www.ai-speaker.com/"
        sandbox="allow-forms allow-popups allow-pointer-lock allow-same-origin allow-scripts"
        allowfullscreen="true"
        webkitallowfullscreen="true"
        mozallowfullscreen="true"
      ></iframe>
    `}static get properties(){return{hass:Object,narrow:Boolean,panel:Object}}}customElements.define("ha-panel-aisdocs",r)}}]);
//# sourceMappingURL=chunk.06346d166395abae9707.js.map