/*! For license information please see chunk.6333adc5b0561e1ac161.js.LICENSE.txt */
(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[4420,7364,9462,1199,6964],{27815:(e,t)=>{"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.shouldPolyfill=void 0,t.shouldPolyfill=function(){return"undefined"==typeof Intl||!("PluralRules"in Intl)||"one"===new Intl.PluralRules("en",{minimumFractionDigits:2}).select(1)}},79332:(e,t,n)=>{"use strict";n.d(t,{a:()=>r});n(43437);const r={properties:{animationConfig:{type:Object},entryAnimation:{observer:"_entryAnimationChanged",type:String},exitAnimation:{observer:"_exitAnimationChanged",type:String}},_entryAnimationChanged:function(){this.animationConfig=this.animationConfig||{},this.animationConfig.entry=[{name:this.entryAnimation,node:this}]},_exitAnimationChanged:function(){this.animationConfig=this.animationConfig||{},this.animationConfig.exit=[{name:this.exitAnimation,node:this}]},_copyProperties:function(e,t){for(var n in t)e[n]=t[n]},_cloneConfig:function(e){var t={isClone:!0};return this._copyProperties(t,e),t},_getAnimationConfigRecursive:function(e,t,n){var r;if(this.animationConfig)if(this.animationConfig.value&&"function"==typeof this.animationConfig.value)this._warn(this._logf("playAnimation","Please put 'animationConfig' inside of your components 'properties' object instead of outside of it."));else if(r=e?this.animationConfig[e]:this.animationConfig,Array.isArray(r)||(r=[r]),r)for(var i,a=0;i=r[a];a++)if(i.animatable)i.animatable._getAnimationConfigRecursive(i.type||e,t,n);else if(i.id){var o=t[i.id];o?(o.isClone||(t[i.id]=this._cloneConfig(o),o=t[i.id]),this._copyProperties(o,i)):t[i.id]=i}else n.push(i)},getAnimationConfig:function(e){var t={},n=[];for(var r in this._getAnimationConfigRecursive(e,t,n),t)n.push(t[r]);return n}}},96540:(e,t,n)=>{"use strict";n.d(t,{t:()=>i});n(43437);const r={_configureAnimations:function(e){var t=[],n=[];if(e.length>0)for(let t,r=0;t=e[r];r++){let e=document.createElement(t.name);if(e.isNeonAnimation){let r=null;e.configure||(e.configure=function(e){return null}),r=e.configure(t),n.push({result:r,config:t,neonAnimation:e})}else console.warn(this.is+":",t.name,"not found!")}for(var r=0;r<n.length;r++){let e=n[r].result,i=n[r].config,a=n[r].neonAnimation;try{"function"!=typeof e.cancel&&(e=document.timeline.play(e))}catch(t){e=null,console.warn("Couldnt play","(",i.name,").",t)}e&&t.push({neonAnimation:a,config:i,animation:e})}return t},_shouldComplete:function(e){for(var t=!0,n=0;n<e.length;n++)if("finished"!=e[n].animation.playState){t=!1;break}return t},_complete:function(e){for(var t=0;t<e.length;t++)e[t].neonAnimation.complete(e[t].config);for(t=0;t<e.length;t++)e[t].animation.cancel()},playAnimation:function(e,t){var n=this.getAnimationConfig(e);if(n){this._active=this._active||{},this._active[e]&&(this._complete(this._active[e]),delete this._active[e]);var r=this._configureAnimations(n);if(0!=r.length){this._active[e]=r;for(var i=0;i<r.length;i++)r[i].animation.onfinish=function(){this._shouldComplete(r)&&(this._complete(r),delete this._active[e],this.fire("neon-animation-finish",t,{bubbles:!1}))}.bind(this)}else this.fire("neon-animation-finish",t,{bubbles:!1})}},cancelAnimation:function(){for(var e in this._active){var t=this._active[e];for(var n in t)t[n].animation.cancel()}this._active={}}},i=[n(79332).a,r]},51654:(e,t,n)=>{"use strict";n.d(t,{Z:()=>a,n:()=>o});n(43437);var r=n(75009),i=n(87156);const a={hostAttributes:{role:"dialog",tabindex:"-1"},properties:{modal:{type:Boolean,value:!1},__readied:{type:Boolean,value:!1}},observers:["_modalChanged(modal, __readied)"],listeners:{tap:"_onDialogClick"},ready:function(){this.__prevNoCancelOnOutsideClick=this.noCancelOnOutsideClick,this.__prevNoCancelOnEscKey=this.noCancelOnEscKey,this.__prevWithBackdrop=this.withBackdrop,this.__readied=!0},_modalChanged:function(e,t){t&&(e?(this.__prevNoCancelOnOutsideClick=this.noCancelOnOutsideClick,this.__prevNoCancelOnEscKey=this.noCancelOnEscKey,this.__prevWithBackdrop=this.withBackdrop,this.noCancelOnOutsideClick=!0,this.noCancelOnEscKey=!0,this.withBackdrop=!0):(this.noCancelOnOutsideClick=this.noCancelOnOutsideClick&&this.__prevNoCancelOnOutsideClick,this.noCancelOnEscKey=this.noCancelOnEscKey&&this.__prevNoCancelOnEscKey,this.withBackdrop=this.withBackdrop&&this.__prevWithBackdrop))},_updateClosingReasonConfirmed:function(e){this.closingReason=this.closingReason||{},this.closingReason.confirmed=e},_onDialogClick:function(e){for(var t=(0,i.vz)(e).path,n=0,r=t.indexOf(this);n<r;n++){var a=t[n];if(a.hasAttribute&&(a.hasAttribute("dialog-dismiss")||a.hasAttribute("dialog-confirm"))){this._updateClosingReasonConfirmed(a.hasAttribute("dialog-confirm")),this.close(),e.stopPropagation();break}}}},o=[r.$,a]},22626:(e,t,n)=>{"use strict";n(43437),n(65660);var r=n(51654),i=n(9672),a=n(50856);(0,i.k)({_template:a.d`
    <style>

      :host {
        display: block;
        @apply --layout-relative;
      }

      :host(.is-scrolled:not(:first-child))::before {
        content: '';
        position: absolute;
        top: 0;
        left: 0;
        right: 0;
        height: 1px;
        background: var(--divider-color);
      }

      :host(.can-scroll:not(.scrolled-to-bottom):not(:last-child))::after {
        content: '';
        position: absolute;
        bottom: 0;
        left: 0;
        right: 0;
        height: 1px;
        background: var(--divider-color);
      }

      .scrollable {
        padding: 0 24px;

        @apply --layout-scroll;
        @apply --paper-dialog-scrollable;
      }

      .fit {
        @apply --layout-fit;
      }
    </style>

    <div id="scrollable" class="scrollable" on-scroll="updateScrollState">
      <slot></slot>
    </div>
`,is:"paper-dialog-scrollable",properties:{dialogElement:{type:Object}},get scrollTarget(){return this.$.scrollable},ready:function(){this._ensureTarget(),this.classList.add("no-padding")},attached:function(){this._ensureTarget(),requestAnimationFrame(this.updateScrollState.bind(this))},updateScrollState:function(){this.toggleClass("is-scrolled",this.scrollTarget.scrollTop>0),this.toggleClass("can-scroll",this.scrollTarget.offsetHeight<this.scrollTarget.scrollHeight),this.toggleClass("scrolled-to-bottom",this.scrollTarget.scrollTop+this.scrollTarget.offsetHeight>=this.scrollTarget.scrollHeight)},_ensureTarget:function(){this.dialogElement=this.dialogElement||this.parentElement,this.dialogElement&&this.dialogElement.behaviors&&this.dialogElement.behaviors.indexOf(r.Z)>=0?(this.dialogElement.sizingTarget=this.scrollTarget,this.scrollTarget.classList.remove("fit")):this.dialogElement&&this.scrollTarget.classList.add("fit")}})},50808:(e,t,n)=>{"use strict";n(43437),n(65660),n(70019),n(54242);const r=document.createElement("template");r.setAttribute("style","display: none;"),r.innerHTML='<dom-module id="paper-dialog-shared-styles">\n  <template>\n    <style>\n      :host {\n        display: block;\n        margin: 24px 40px;\n\n        background: var(--paper-dialog-background-color, var(--primary-background-color));\n        color: var(--paper-dialog-color, var(--primary-text-color));\n\n        @apply --paper-font-body1;\n        @apply --shadow-elevation-16dp;\n        @apply --paper-dialog;\n      }\n\n      :host > ::slotted(*) {\n        margin-top: 20px;\n        padding: 0 24px;\n      }\n\n      :host > ::slotted(.no-padding) {\n        padding: 0;\n      }\n\n      \n      :host > ::slotted(*:first-child) {\n        margin-top: 24px;\n      }\n\n      :host > ::slotted(*:last-child) {\n        margin-bottom: 24px;\n      }\n\n      /* In 1.x, this selector was `:host > ::content h2`. In 2.x <slot> allows\n      to select direct children only, which increases the weight of this\n      selector, so we have to re-define first-child/last-child margins below. */\n      :host > ::slotted(h2) {\n        position: relative;\n        margin: 0;\n\n        @apply --paper-font-title;\n        @apply --paper-dialog-title;\n      }\n\n      /* Apply mixin again, in case it sets margin-top. */\n      :host > ::slotted(h2:first-child) {\n        margin-top: 24px;\n        @apply --paper-dialog-title;\n      }\n\n      /* Apply mixin again, in case it sets margin-bottom. */\n      :host > ::slotted(h2:last-child) {\n        margin-bottom: 24px;\n        @apply --paper-dialog-title;\n      }\n\n      :host > ::slotted(.paper-dialog-buttons),\n      :host > ::slotted(.buttons) {\n        position: relative;\n        padding: 8px 8px 8px 24px;\n        margin: 0;\n\n        color: var(--paper-dialog-button-color, var(--primary-color));\n\n        @apply --layout-horizontal;\n        @apply --layout-end-justified;\n      }\n    </style>\n  </template>\n</dom-module>',document.head.appendChild(r.content);var i=n(96540),a=n(51654),o=n(9672),s=n(50856);(0,o.k)({_template:s.d`
    <style include="paper-dialog-shared-styles"></style>
    <slot></slot>
`,is:"paper-dialog",behaviors:[a.n,i.t],listeners:{"neon-animation-finish":"_onNeonAnimationFinish"},_renderOpened:function(){this.cancelAnimation(),this.playAnimation("entry")},_renderClosed:function(){this.cancelAnimation(),this.playAnimation("exit")},_onNeonAnimationFinish:function(){this.opened?this._finishRenderOpened():this._finishRenderClosed()}})},25856:(e,t,n)=>{"use strict";n(43437),n(65660);var r=n(26110),i=n(98235),a=n(9672),o=n(87156),s=n(50856);(0,a.k)({_template:s.d`
    <style>
      :host {
        display: inline-block;
        position: relative;
        width: 400px;
        border: 1px solid;
        padding: 2px;
        -moz-appearance: textarea;
        -webkit-appearance: textarea;
        overflow: hidden;
      }

      .mirror-text {
        visibility: hidden;
        word-wrap: break-word;
        @apply --iron-autogrow-textarea;
      }

      .fit {
        @apply --layout-fit;
      }

      textarea {
        position: relative;
        outline: none;
        border: none;
        resize: none;
        background: inherit;
        color: inherit;
        /* see comments in template */
        width: 100%;
        height: 100%;
        font-size: inherit;
        font-family: inherit;
        line-height: inherit;
        text-align: inherit;
        @apply --iron-autogrow-textarea;
      }

      textarea::-webkit-input-placeholder {
        @apply --iron-autogrow-textarea-placeholder;
      }

      textarea:-moz-placeholder {
        @apply --iron-autogrow-textarea-placeholder;
      }

      textarea::-moz-placeholder {
        @apply --iron-autogrow-textarea-placeholder;
      }

      textarea:-ms-input-placeholder {
        @apply --iron-autogrow-textarea-placeholder;
      }
    </style>

    <!-- the mirror sizes the input/textarea so it grows with typing -->
    <!-- use &#160; instead &nbsp; of to allow this element to be used in XHTML -->
    <div id="mirror" class="mirror-text" aria-hidden="true">&nbsp;</div>

    <!-- size the input/textarea with a div, because the textarea has intrinsic size in ff -->
    <div class="textarea-container fit">
      <textarea id="textarea" name\$="[[name]]" aria-label\$="[[label]]" autocomplete\$="[[autocomplete]]" autofocus\$="[[autofocus]]" inputmode\$="[[inputmode]]" placeholder\$="[[placeholder]]" readonly\$="[[readonly]]" required\$="[[required]]" disabled\$="[[disabled]]" rows\$="[[rows]]" minlength\$="[[minlength]]" maxlength\$="[[maxlength]]"></textarea>
    </div>
`,is:"iron-autogrow-textarea",behaviors:[i.x,r.a],properties:{value:{observer:"_valueChanged",type:String,notify:!0},bindValue:{observer:"_bindValueChanged",type:String,notify:!0},rows:{type:Number,value:1,observer:"_updateCached"},maxRows:{type:Number,value:0,observer:"_updateCached"},autocomplete:{type:String,value:"off"},autofocus:{type:Boolean,value:!1},inputmode:{type:String},placeholder:{type:String},readonly:{type:String},required:{type:Boolean},minlength:{type:Number},maxlength:{type:Number},label:{type:String}},listeners:{input:"_onInput"},get textarea(){return this.$.textarea},get selectionStart(){return this.$.textarea.selectionStart},get selectionEnd(){return this.$.textarea.selectionEnd},set selectionStart(e){this.$.textarea.selectionStart=e},set selectionEnd(e){this.$.textarea.selectionEnd=e},attached:function(){navigator.userAgent.match(/iP(?:[oa]d|hone)/)&&(this.$.textarea.style.marginLeft="-3px")},validate:function(){var e=this.$.textarea.validity.valid;return e&&(this.required&&""===this.value?e=!1:this.hasValidator()&&(e=i.x.validate.call(this,this.value))),this.invalid=!e,this.fire("iron-input-validate"),e},_bindValueChanged:function(e){this.value=e},_valueChanged:function(e){var t=this.textarea;t&&(t.value!==e&&(t.value=e||0===e?e:""),this.bindValue=e,this.$.mirror.innerHTML=this._valueForMirror(),this.fire("bind-value-changed",{value:this.bindValue}))},_onInput:function(e){var t=(0,o.vz)(e).path;this.value=t?t[0].value:e.target.value},_constrain:function(e){var t;for(e=e||[""],t=this.maxRows>0&&e.length>this.maxRows?e.slice(0,this.maxRows):e.slice(0);this.rows>0&&t.length<this.rows;)t.push("");return t.join("<br/>")+"&#160;"},_valueForMirror:function(){var e=this.textarea;if(e)return this.tokens=e&&e.value?e.value.replace(/&/gm,"&amp;").replace(/"/gm,"&quot;").replace(/'/gm,"&#39;").replace(/</gm,"&lt;").replace(/>/gm,"&gt;").split("\n"):[""],this._constrain(this.tokens)},_updateCached:function(){this.$.mirror.innerHTML=this._constrain(this.tokens)}});n(2178),n(98121),n(65911);var l=n(21006),u=n(66668);(0,a.k)({_template:s.d`
    <style>
      :host {
        display: block;
      }

      :host([hidden]) {
        display: none !important;
      }

      label {
        pointer-events: none;
      }
    </style>

    <paper-input-container no-label-float$="[[noLabelFloat]]" always-float-label="[[_computeAlwaysFloatLabel(alwaysFloatLabel,placeholder)]]" auto-validate$="[[autoValidate]]" disabled$="[[disabled]]" invalid="[[invalid]]">

      <label hidden$="[[!label]]" aria-hidden="true" for$="[[_inputId]]" slot="label">[[label]]</label>

      <iron-autogrow-textarea class="paper-input-input" slot="input" id$="[[_inputId]]" aria-labelledby$="[[_ariaLabelledBy]]" aria-describedby$="[[_ariaDescribedBy]]" bind-value="{{value}}" invalid="{{invalid}}" validator$="[[validator]]" disabled$="[[disabled]]" autocomplete$="[[autocomplete]]" autofocus$="[[autofocus]]" inputmode$="[[inputmode]]" name$="[[name]]" placeholder$="[[placeholder]]" readonly$="[[readonly]]" required$="[[required]]" minlength$="[[minlength]]" maxlength$="[[maxlength]]" autocapitalize$="[[autocapitalize]]" rows$="[[rows]]" max-rows$="[[maxRows]]" on-change="_onChange"></iron-autogrow-textarea>

      <template is="dom-if" if="[[errorMessage]]">
        <paper-input-error aria-live="assertive" slot="add-on">[[errorMessage]]</paper-input-error>
      </template>

      <template is="dom-if" if="[[charCounter]]">
        <paper-input-char-counter slot="add-on"></paper-input-char-counter>
      </template>

    </paper-input-container>
`,is:"paper-textarea",behaviors:[u.d0,l.V],properties:{_ariaLabelledBy:{observer:"_ariaLabelledByChanged",type:String},_ariaDescribedBy:{observer:"_ariaDescribedByChanged",type:String},value:{type:String},rows:{type:Number,value:1},maxRows:{type:Number,value:0}},get selectionStart(){return this.$.input.textarea.selectionStart},set selectionStart(e){this.$.input.textarea.selectionStart=e},get selectionEnd(){return this.$.input.textarea.selectionEnd},set selectionEnd(e){this.$.input.textarea.selectionEnd=e},_ariaLabelledByChanged:function(e){this._focusableElement.setAttribute("aria-labelledby",e)},_ariaDescribedByChanged:function(e){this._focusableElement.setAttribute("aria-describedby",e)},get _focusableElement(){return this.inputElement.textarea}})},60461:e=>{e.exports=function e(t){return Object.freeze(t),Object.getOwnPropertyNames(t).forEach((function(n){!t.hasOwnProperty(n)||null===t[n]||"object"!=typeof t[n]&&"function"!=typeof t[n]||Object.isFrozen(t[n])||e(t[n])})),t}},95282:(e,t,n)=>{"use strict";n.d(t,{_:()=>i,B:()=>a});var r=n(12902);const i=(e,t,n,i)=>{if(e[t])return e[t];let a,o=0,s=(0,r.M)();const l=()=>n(e).then((e=>s.setState(e,!0))),u=()=>l().catch((t=>{if(e.connected)throw t}));return e[t]={get state(){return s.state},refresh:l,subscribe(t){o++,1===o&&(i&&(a=i(e,s)),e.addEventListener("ready",u),u());const n=s.subscribe(t);return void 0!==s.state&&setTimeout((()=>t(s.state)),0),()=>{n(),o--,o||(a&&a.then((e=>{e()})),e.removeEventListener("ready",l))}}},e[t]},a=(e,t,n,r,a)=>i(r,e,t,n).subscribe(a)},23553:(e,t,n)=>{"use strict";n.d(t,{Pz:()=>i,U2:()=>a,iE:()=>o,PR:()=>s,_D:()=>l});var r=n(36007);const i=e=>e.sendMessagePromise(r.$q()),a=e=>e.sendMessagePromise(r.uZ()),o=e=>e.sendMessagePromise(r.vc()),s=e=>e.sendMessagePromise(r.EA()),l=(e,t,n,i)=>e.sendMessagePromise(r._D(t,n,i))},4915:(e,t,n)=>{"use strict";n.d(t,{wQ:()=>l,UE:()=>u,dL:()=>c,u5:()=>p});var r=n(95282),i=n(23553);function a(e,t){return void 0===e?null:{components:e.components.concat(t.data.component)}}const o=e=>(0,i.iE)(e),s=(e,t)=>Promise.all([e.subscribeEvents(t.action(a),"component_loaded"),e.subscribeEvents((()=>o(e).then((e=>t.setState(e,!0)))),"core_config_updated")]).then((e=>()=>e.forEach((e=>e())))),l=(e,t)=>(e=>(0,r._)(e,"_cnf",o,s))(e).subscribe(t),u="NOT_RUNNING",c="STARTING",p="RUNNING"},36007:(e,t,n)=>{"use strict";function r(e){return{type:"auth",access_token:e}}function i(){return{type:"get_states"}}function a(){return{type:"get_config"}}function o(){return{type:"get_services"}}function s(){return{type:"auth/current_user"}}function l(e,t,n){const r={type:"call_service",domain:e,service:t};return n&&(r.service_data=n),r}function u(e){const t={type:"subscribe_events"};return e&&(t.event_type=e),t}function c(e){return{type:"unsubscribe_events",subscription:e}}function p(){return{type:"ping"}}function h(e,t){return{type:"result",success:!1,error:{code:e,message:t}}}n.d(t,{I8:()=>r,$q:()=>i,vc:()=>a,uZ:()=>o,EA:()=>s,_D:()=>l,a:()=>u,Mt:()=>c,qE:()=>p,vU:()=>h})},12902:(e,t,n)=>{"use strict";n.d(t,{M:()=>r});const r=e=>{let t=[];function n(n,r){e=r?n:Object.assign(Object.assign({},e),n);let i=t;for(let t=0;t<i.length;t++)i[t](e)}return{get state(){return e},action(t){function r(e){n(e,!1)}return function(){let n=[e];for(let e=0;e<arguments.length;e++)n.push(arguments[e]);let i=t.apply(this,n);if(null!=i)return i instanceof Promise?i.then(r):r(i)}},setState:n,subscribe:e=>(t.push(e),()=>{!function(e){let n=[];for(let r=0;r<t.length;r++)t[r]===e?e=null:n.push(t[r]);t=n}(e)})}}},21602:(e,t,n)=>{"use strict";var r,i;function a(e){return e.type===r.literal}function o(e){return e.type===r.argument}function s(e){return e.type===r.number}function l(e){return e.type===r.date}function u(e){return e.type===r.time}function c(e){return e.type===r.select}function p(e){return e.type===r.plural}function h(e){return e.type===r.pound}function f(e){return e.type===r.tag}function d(e){return!(!e||"object"!=typeof e||0!==e.type)}function g(e){return!(!e||"object"!=typeof e||1!==e.type)}n.d(t,{ZP:()=>K}),function(e){e[e.literal=0]="literal",e[e.argument=1]="argument",e[e.number=2]="number",e[e.date=3]="date",e[e.time=4]="time",e[e.select=5]="select",e[e.plural=6]="plural",e[e.pound=7]="pound",e[e.tag=8]="tag"}(r||(r={})),function(e){e[e.number=0]="number",e[e.dateTime=1]="dateTime"}(i||(i={}));var m,v=(m=function(e,t){return(m=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(e,t)},function(e,t){function n(){this.constructor=e}m(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),y=function(){return(y=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},b=function(e){function t(n,r,i,a){var o=e.call(this)||this;return o.message=n,o.expected=r,o.found=i,o.location=a,o.name="SyntaxError","function"==typeof Error.captureStackTrace&&Error.captureStackTrace(o,t),o}return v(t,e),t.buildMessage=function(e,t){function n(e){return e.charCodeAt(0).toString(16).toUpperCase()}function r(e){return e.replace(/\\/g,"\\\\").replace(/"/g,'\\"').replace(/\0/g,"\\0").replace(/\t/g,"\\t").replace(/\n/g,"\\n").replace(/\r/g,"\\r").replace(/[\x00-\x0F]/g,(function(e){return"\\x0"+n(e)})).replace(/[\x10-\x1F\x7F-\x9F]/g,(function(e){return"\\x"+n(e)}))}function i(e){return e.replace(/\\/g,"\\\\").replace(/\]/g,"\\]").replace(/\^/g,"\\^").replace(/-/g,"\\-").replace(/\0/g,"\\0").replace(/\t/g,"\\t").replace(/\n/g,"\\n").replace(/\r/g,"\\r").replace(/[\x00-\x0F]/g,(function(e){return"\\x0"+n(e)})).replace(/[\x10-\x1F\x7F-\x9F]/g,(function(e){return"\\x"+n(e)}))}function a(e){switch(e.type){case"literal":return'"'+r(e.text)+'"';case"class":var t=e.parts.map((function(e){return Array.isArray(e)?i(e[0])+"-"+i(e[1]):i(e)}));return"["+(e.inverted?"^":"")+t+"]";case"any":return"any character";case"end":return"end of input";case"other":return e.description}}return"Expected "+function(e){var t,n,r=e.map(a);if(r.sort(),r.length>0){for(t=1,n=1;t<r.length;t++)r[t-1]!==r[t]&&(r[n]=r[t],n++);r.length=n}switch(r.length){case 1:return r[0];case 2:return r[0]+" or "+r[1];default:return r.slice(0,-1).join(", ")+", or "+r[r.length-1]}}(e)+" but "+(((o=t)?'"'+r(o)+'"':"end of input")+" found.");var o},t}(Error);var A=function(e,t){t=void 0!==t?t:{};var n,i={},a={start:Ge},o=Ge,s=Be("#",!1),l=Ve("tagElement"),u="<",c=Be("<",!1),p="/>",h=Be("/>",!1),f=">",d=Be(">",!1),g=function(e){return gt.pop(),!0},m="</",v=Be("</",!1),A=Ve("argumentElement"),_="{",w=Be("{",!1),x="}",C=Be("}",!1),k=Ve("numberSkeletonId"),E=/^['\/{}]/,O=Me(["'","/","{","}"],!1,!1),S={type:"any"},D=Ve("numberSkeletonTokenOption"),$=Be("/",!1),F=Ve("numberSkeletonToken"),T="::",I=Be("::",!1),N=function(e){return gt.pop(),e.replace(/\s*$/,"")},R=",",j=Be(",",!1),P="number",L=Be("number",!1),z=function(e,t,n){return y({type:"number"===t?r.number:"date"===t?r.date:r.time,style:n&&n[2],value:e},yt())},B="'",M=Be("'",!1),V=/^[^']/,Z=Me(["'"],!0,!1),U=/^[^a-zA-Z'{}]/,q=Me([["a","z"],["A","Z"],"'","{","}"],!0,!1),H=/^[a-zA-Z]/,G=Me([["a","z"],["A","Z"]],!1,!1),K="date",W=Be("date",!1),Q="time",X=Be("time",!1),J="plural",Y=Be("plural",!1),ee="selectordinal",te=Be("selectordinal",!1),ne="offset:",re=Be("offset:",!1),ie="select",ae=Be("select",!1),oe=Be("=",!1),se=Ve("whitespace"),le=/^[\t-\r \x85\xA0\u1680\u2000-\u200A\u2028\u2029\u202F\u205F\u3000]/,ue=Me([["\t","\r"]," ",""," "," ",[" "," "],"\u2028","\u2029"," "," ","　"],!1,!1),ce=Ve("syntax pattern"),pe=/^[!-\/:-@[-\^`{-~\xA1-\xA7\xA9\xAB\xAC\xAE\xB0\xB1\xB6\xBB\xBF\xD7\xF7\u2010-\u2027\u2030-\u203E\u2041-\u2053\u2055-\u205E\u2190-\u245F\u2500-\u2775\u2794-\u2BFF\u2E00-\u2E7F\u3001-\u3003\u3008-\u3020\u3030\uFD3E\uFD3F\uFE45\uFE46]/,he=Me([["!","/"],[":","@"],["[","^"],"`",["{","~"],["¡","§"],"©","«","¬","®","°","±","¶","»","¿","×","÷",["‐","‧"],["‰","‾"],["⁁","⁓"],["⁕","⁞"],["←","⑟"],["─","❵"],["➔","⯿"],["⸀","⹿"],["、","〃"],["〈","〠"],"〰","﴾","﴿","﹅","﹆"],!1,!1),fe=Ve("optional whitespace"),de=Ve("number"),ge="-",me=Be("-",!1),ve=(Ve("apostrophe"),Ve("double apostrophes")),ye="''",be=Be("''",!1),Ae=Be("\n",!1),_e=Ve("argNameOrNumber"),we=Ve("validTag"),xe=Ve("argNumber"),Ce=Be("0",!1),ke=/^[1-9]/,Ee=Me([["1","9"]],!1,!1),Oe=/^[0-9]/,Se=Me([["0","9"]],!1,!1),De=Ve("argName"),$e=Ve("tagName"),Fe=0,Te=0,Ie=[{line:1,column:1}],Ne=0,Re=[],je=0;if(void 0!==t.startRule){if(!(t.startRule in a))throw new Error("Can't start parsing from rule \""+t.startRule+'".');o=a[t.startRule]}function Pe(){return e.substring(Te,Fe)}function Le(){return Ue(Te,Fe)}function ze(e,t){throw function(e,t){return new b(e,[],"",t)}(e,t=void 0!==t?t:Ue(Te,Fe))}function Be(e,t){return{type:"literal",text:e,ignoreCase:t}}function Me(e,t,n){return{type:"class",parts:e,inverted:t,ignoreCase:n}}function Ve(e){return{type:"other",description:e}}function Ze(t){var n,r=Ie[t];if(r)return r;for(n=t-1;!Ie[n];)n--;for(r={line:(r=Ie[n]).line,column:r.column};n<t;)10===e.charCodeAt(n)?(r.line++,r.column=1):r.column++,n++;return Ie[t]=r,r}function Ue(e,t){var n=Ze(e),r=Ze(t);return{start:{offset:e,line:n.line,column:n.column},end:{offset:t,line:r.line,column:r.column}}}function qe(e){Fe<Ne||(Fe>Ne&&(Ne=Fe,Re=[]),Re.push(e))}function He(e,t,n){return new b(b.buildMessage(e,t),e,t,n)}function Ge(){return Ke()}function Ke(){var e,t;for(e=[],t=We();t!==i;)e.push(t),t=We();return e}function We(){var t;return(t=function(){var e,t;e=Fe,(t=Qe())!==i&&(Te=e,n=t,t=y({type:r.literal,value:n},yt()));var n;return e=t}())===i&&(t=function(){var t,n,a,o;je++,t=Fe,123===e.charCodeAt(Fe)?(n=_,Fe++):(n=i,0===je&&qe(w));n!==i&&ot()!==i&&(a=pt())!==i&&ot()!==i?(125===e.charCodeAt(Fe)?(o=x,Fe++):(o=i,0===je&&qe(C)),o!==i?(Te=t,s=a,t=n=y({type:r.argument,value:s},yt())):(Fe=t,t=i)):(Fe=t,t=i);var s;je--,t===i&&(n=i,0===je&&qe(A));return t}())===i&&(t=function(){var t;(t=function(){var t,n,r,a,o,s,l,u,c;t=Fe,123===e.charCodeAt(Fe)?(n=_,Fe++):(n=i,0===je&&qe(w));n!==i&&ot()!==i&&(r=pt())!==i&&ot()!==i?(44===e.charCodeAt(Fe)?(a=R,Fe++):(a=i,0===je&&qe(j)),a!==i&&ot()!==i?(e.substr(Fe,6)===P?(o=P,Fe+=6):(o=i,0===je&&qe(L)),o!==i&&ot()!==i?(s=Fe,44===e.charCodeAt(Fe)?(l=R,Fe++):(l=i,0===je&&qe(j)),l!==i&&(u=ot())!==i&&(c=function(){var t,n,r;t=Fe,e.substr(Fe,2)===T?(n=T,Fe+=2):(n=i,0===je&&qe(I));n!==i&&(r=function(){var e,t,n;if(e=Fe,t=[],(n=Ye())!==i)for(;n!==i;)t.push(n),n=Ye();else t=i;t!==i&&(Te=e,t=y({type:0,tokens:t},yt()));return e=t}())!==i?(Te=t,t=n=r):(Fe=t,t=i);t===i&&(t=Fe,Te=Fe,gt.push("numberArgStyle"),(n=(n=!0)?void 0:i)!==i&&(r=Qe())!==i?(Te=t,t=n=N(r)):(Fe=t,t=i));return t}())!==i?s=l=[l,u,c]:(Fe=s,s=i),s===i&&(s=null),s!==i&&(l=ot())!==i?(125===e.charCodeAt(Fe)?(u=x,Fe++):(u=i,0===je&&qe(C)),u!==i?(Te=t,t=n=z(r,o,s)):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i);return t}())===i&&(t=function(){var t,n,r,a,o,s,l,u,c;t=Fe,123===e.charCodeAt(Fe)?(n=_,Fe++):(n=i,0===je&&qe(w));n!==i&&ot()!==i&&(r=pt())!==i&&ot()!==i?(44===e.charCodeAt(Fe)?(a=R,Fe++):(a=i,0===je&&qe(j)),a!==i&&ot()!==i?(e.substr(Fe,4)===K?(o=K,Fe+=4):(o=i,0===je&&qe(W)),o===i&&(e.substr(Fe,4)===Q?(o=Q,Fe+=4):(o=i,0===je&&qe(X))),o!==i&&ot()!==i?(s=Fe,44===e.charCodeAt(Fe)?(l=R,Fe++):(l=i,0===je&&qe(j)),l!==i&&(u=ot())!==i&&(c=function(){var t,n,r;t=Fe,e.substr(Fe,2)===T?(n=T,Fe+=2):(n=i,0===je&&qe(I));n!==i&&(r=function(){var t,n,r,a;t=Fe,n=Fe,r=[],(a=et())===i&&(a=tt());if(a!==i)for(;a!==i;)r.push(a),(a=et())===i&&(a=tt());else r=i;n=r!==i?e.substring(n,Fe):r;n!==i&&(Te=t,n=y({type:1,pattern:n},yt()));return t=n}())!==i?(Te=t,t=n=r):(Fe=t,t=i);t===i&&(t=Fe,Te=Fe,gt.push("dateOrTimeArgStyle"),(n=(n=!0)?void 0:i)!==i&&(r=Qe())!==i?(Te=t,t=n=N(r)):(Fe=t,t=i));return t}())!==i?s=l=[l,u,c]:(Fe=s,s=i),s===i&&(s=null),s!==i&&(l=ot())!==i?(125===e.charCodeAt(Fe)?(u=x,Fe++):(u=i,0===je&&qe(C)),u!==i?(Te=t,t=n=z(r,o,s)):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i);return t}());return t}())===i&&(t=function(){var t,n,a,o,s,l,u,c,p,h,f;t=Fe,123===e.charCodeAt(Fe)?(n=_,Fe++):(n=i,0===je&&qe(w));if(n!==i)if(ot()!==i)if((a=pt())!==i)if(ot()!==i)if(44===e.charCodeAt(Fe)?(o=R,Fe++):(o=i,0===je&&qe(j)),o!==i)if(ot()!==i)if(e.substr(Fe,6)===J?(s=J,Fe+=6):(s=i,0===je&&qe(Y)),s===i&&(e.substr(Fe,13)===ee?(s=ee,Fe+=13):(s=i,0===je&&qe(te))),s!==i)if(ot()!==i)if(44===e.charCodeAt(Fe)?(l=R,Fe++):(l=i,0===je&&qe(j)),l!==i)if(ot()!==i)if(u=Fe,e.substr(Fe,7)===ne?(c=ne,Fe+=7):(c=i,0===je&&qe(re)),c!==i&&(p=ot())!==i&&(h=st())!==i?u=c=[c,p,h]:(Fe=u,u=i),u===i&&(u=null),u!==i)if((c=ot())!==i){if(p=[],(h=rt())!==i)for(;h!==i;)p.push(h),h=rt();else p=i;p!==i&&(h=ot())!==i?(125===e.charCodeAt(Fe)?(f=x,Fe++):(f=i,0===je&&qe(C)),f!==i?(Te=t,t=n=function(e,t,n,i){return y({type:r.plural,pluralType:"plural"===t?"cardinal":"ordinal",value:e,offset:n?n[2]:0,options:i.reduce((function(e,t){var n=t.id,r=t.value,i=t.location;return n in e&&ze('Duplicate option "'+n+'" in plural element: "'+Pe()+'"',Le()),e[n]={value:r,location:i},e}),{})},yt())}(a,s,u,p)):(Fe=t,t=i)):(Fe=t,t=i)}else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;return t}())===i&&(t=function(){var t,n,a,o,s,l,u,c,p;t=Fe,123===e.charCodeAt(Fe)?(n=_,Fe++):(n=i,0===je&&qe(w));if(n!==i)if(ot()!==i)if((a=pt())!==i)if(ot()!==i)if(44===e.charCodeAt(Fe)?(o=R,Fe++):(o=i,0===je&&qe(j)),o!==i)if(ot()!==i)if(e.substr(Fe,6)===ie?(s=ie,Fe+=6):(s=i,0===je&&qe(ae)),s!==i)if(ot()!==i)if(44===e.charCodeAt(Fe)?(l=R,Fe++):(l=i,0===je&&qe(j)),l!==i)if(ot()!==i){if(u=[],(c=nt())!==i)for(;c!==i;)u.push(c),c=nt();else u=i;u!==i&&(c=ot())!==i?(125===e.charCodeAt(Fe)?(p=x,Fe++):(p=i,0===je&&qe(C)),p!==i?(Te=t,t=n=function(e,t){return y({type:r.select,value:e,options:t.reduce((function(e,t){var n=t.id,r=t.value,i=t.location;return n in e&&ze('Duplicate option "'+n+'" in select element: "'+Pe()+'"',Le()),e[n]={value:r,location:i},e}),{})},yt())}(a,u)):(Fe=t,t=i)):(Fe=t,t=i)}else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;else Fe=t,t=i;return t}())===i&&(t=function(){var t,n,a,o,s,b;je++,t=Fe,n=Fe,60===e.charCodeAt(Fe)?(a="<",Fe++):(a=i,0===je&&qe(c));a!==i&&(o=ht())!==i&&(s=ot())!==i?(e.substr(Fe,2)===p?(b=p,Fe+=2):(b=i,0===je&&qe(h)),b!==i?n=a=[a,o,s,b]:(Fe=n,n=i)):(Fe=n,n=i);n!==i&&(Te=t,A=n,n=y({type:r.literal,value:A.join("")},yt()));var A;(t=n)===i&&(t=Fe,(n=function(){var t,n,r,a;t=Fe,60===e.charCodeAt(Fe)?(n=u,Fe++):(n=i,0===je&&qe(c));n!==i?(Te=Fe,gt.push("openingTag"),(!0?void 0:i)!==i&&(r=ht())!==i?(62===e.charCodeAt(Fe)?(a=">",Fe++):(a=i,0===je&&qe(d)),a!==i?(Te=Fe,(g()?void 0:i)!==i?(Te=t,t=n=r):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i);return t}())!==i&&(a=Ke())!==i&&(o=function(){var t,n,r,a;t=Fe,e.substr(Fe,2)===m?(n=m,Fe+=2):(n=i,0===je&&qe(v));n!==i?(Te=Fe,gt.push("closingTag"),(!0?void 0:i)!==i&&(r=ht())!==i?(62===e.charCodeAt(Fe)?(a=f,Fe++):(a=i,0===je&&qe(d)),a!==i?(Te=Fe,(g()?void 0:i)!==i?(Te=t,t=n=r):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i);return t}())!==i?(Te=t,w=a,(_=n)!==(x=o)&&ze('Mismatch tag "'+_+'" !== "'+x+'"',Le()),t=n=y({type:r.tag,value:_,children:w},yt())):(Fe=t,t=i));var _,w,x;je--,t===i&&(n=i,0===je&&qe(l));return t}())===i&&(t=function(){var t,n;t=Fe,35===e.charCodeAt(Fe)?(n="#",Fe++):(n=i,0===je&&qe(s));n!==i&&(Te=t,n=y({type:r.pound},yt()));return t=n}()),t}function Qe(){var e,t,n;if(e=Fe,t=[],(n=lt())===i&&(n=ut())===i&&(n=ct()),n!==i)for(;n!==i;)t.push(n),(n=lt())===i&&(n=ut())===i&&(n=ct());else t=i;return t!==i&&(Te=e,t=t.join("")),e=t}function Xe(){var t,n,r,a,o;if(je++,t=Fe,n=[],r=Fe,a=Fe,je++,(o=it())===i&&(E.test(e.charAt(Fe))?(o=e.charAt(Fe),Fe++):(o=i,0===je&&qe(O))),je--,o===i?a=void 0:(Fe=a,a=i),a!==i?(e.length>Fe?(o=e.charAt(Fe),Fe++):(o=i,0===je&&qe(S)),o!==i?r=a=[a,o]:(Fe=r,r=i)):(Fe=r,r=i),r!==i)for(;r!==i;)n.push(r),r=Fe,a=Fe,je++,(o=it())===i&&(E.test(e.charAt(Fe))?(o=e.charAt(Fe),Fe++):(o=i,0===je&&qe(O))),je--,o===i?a=void 0:(Fe=a,a=i),a!==i?(e.length>Fe?(o=e.charAt(Fe),Fe++):(o=i,0===je&&qe(S)),o!==i?r=a=[a,o]:(Fe=r,r=i)):(Fe=r,r=i);else n=i;return t=n!==i?e.substring(t,Fe):n,je--,t===i&&(n=i,0===je&&qe(k)),t}function Je(){var t,n,r;return je++,t=Fe,47===e.charCodeAt(Fe)?(n="/",Fe++):(n=i,0===je&&qe($)),n!==i&&(r=Xe())!==i?(Te=t,t=n=r):(Fe=t,t=i),je--,t===i&&(n=i,0===je&&qe(D)),t}function Ye(){var e,t,n,r;if(je++,e=Fe,ot()!==i)if((t=Xe())!==i){for(n=[],r=Je();r!==i;)n.push(r),r=Je();n!==i?(Te=e,e=function(e,t){return{stem:e,options:t}}(t,n)):(Fe=e,e=i)}else Fe=e,e=i;else Fe=e,e=i;return je--,e===i&&(i,0===je&&qe(F)),e}function et(){var t,n,r,a;if(t=Fe,39===e.charCodeAt(Fe)?(n=B,Fe++):(n=i,0===je&&qe(M)),n!==i){if(r=[],(a=lt())===i&&(V.test(e.charAt(Fe))?(a=e.charAt(Fe),Fe++):(a=i,0===je&&qe(Z))),a!==i)for(;a!==i;)r.push(a),(a=lt())===i&&(V.test(e.charAt(Fe))?(a=e.charAt(Fe),Fe++):(a=i,0===je&&qe(Z)));else r=i;r!==i?(39===e.charCodeAt(Fe)?(a=B,Fe++):(a=i,0===je&&qe(M)),a!==i?t=n=[n,r,a]:(Fe=t,t=i)):(Fe=t,t=i)}else Fe=t,t=i;if(t===i)if(t=[],(n=lt())===i&&(U.test(e.charAt(Fe))?(n=e.charAt(Fe),Fe++):(n=i,0===je&&qe(q))),n!==i)for(;n!==i;)t.push(n),(n=lt())===i&&(U.test(e.charAt(Fe))?(n=e.charAt(Fe),Fe++):(n=i,0===je&&qe(q)));else t=i;return t}function tt(){var t,n;if(t=[],H.test(e.charAt(Fe))?(n=e.charAt(Fe),Fe++):(n=i,0===je&&qe(G)),n!==i)for(;n!==i;)t.push(n),H.test(e.charAt(Fe))?(n=e.charAt(Fe),Fe++):(n=i,0===je&&qe(G));else t=i;return t}function nt(){var t,n,r,a,o,s,l;return t=Fe,ot()!==i&&(n=dt())!==i&&ot()!==i?(123===e.charCodeAt(Fe)?(r=_,Fe++):(r=i,0===je&&qe(w)),r!==i?(Te=Fe,gt.push("select"),(!0?void 0:i)!==i&&(a=Ke())!==i?(125===e.charCodeAt(Fe)?(o=x,Fe++):(o=i,0===je&&qe(C)),o!==i?(Te=t,s=n,l=a,gt.pop(),t=y({id:s,value:l},yt())):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i),t}function rt(){var t,n,r,a,o,s,l;return t=Fe,ot()!==i&&(n=function(){var t,n,r,a;return t=Fe,n=Fe,61===e.charCodeAt(Fe)?(r="=",Fe++):(r=i,0===je&&qe(oe)),r!==i&&(a=st())!==i?n=r=[r,a]:(Fe=n,n=i),(t=n!==i?e.substring(t,Fe):n)===i&&(t=dt()),t}())!==i&&ot()!==i?(123===e.charCodeAt(Fe)?(r=_,Fe++):(r=i,0===je&&qe(w)),r!==i?(Te=Fe,gt.push("plural"),(!0?void 0:i)!==i&&(a=Ke())!==i?(125===e.charCodeAt(Fe)?(o=x,Fe++):(o=i,0===je&&qe(C)),o!==i?(Te=t,s=n,l=a,gt.pop(),t=y({id:s,value:l},yt())):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i)):(Fe=t,t=i),t}function it(){var t;return je++,le.test(e.charAt(Fe))?(t=e.charAt(Fe),Fe++):(t=i,0===je&&qe(ue)),je--,t===i&&(i,0===je&&qe(se)),t}function at(){var t;return je++,pe.test(e.charAt(Fe))?(t=e.charAt(Fe),Fe++):(t=i,0===je&&qe(he)),je--,t===i&&(i,0===je&&qe(ce)),t}function ot(){var t,n,r;for(je++,t=Fe,n=[],r=it();r!==i;)n.push(r),r=it();return t=n!==i?e.substring(t,Fe):n,je--,t===i&&(n=i,0===je&&qe(fe)),t}function st(){var t,n,r,a,o;return je++,t=Fe,45===e.charCodeAt(Fe)?(n="-",Fe++):(n=i,0===je&&qe(me)),n===i&&(n=null),n!==i&&(r=ft())!==i?(Te=t,a=n,t=n=(o=r)?a?-o:o:0):(Fe=t,t=i),je--,t===i&&(n=i,0===je&&qe(de)),t}function lt(){var t,n;return je++,t=Fe,e.substr(Fe,2)===ye?(n=ye,Fe+=2):(n=i,0===je&&qe(be)),n!==i&&(Te=t,n="'"),je--,(t=n)===i&&(n=i,0===je&&qe(ve)),t}function ut(){var t,n,r,a,o,s;if(t=Fe,39===e.charCodeAt(Fe)?(n=B,Fe++):(n=i,0===je&&qe(M)),n!==i)if((r=function(){var t,n,r,a;t=Fe,n=Fe,e.length>Fe?(r=e.charAt(Fe),Fe++):(r=i,0===je&&qe(S));r!==i?(Te=Fe,(a=(a="<"===(o=r)||">"===o||"{"===o||"}"===o||vt()&&"#"===o)?void 0:i)!==i?n=r=[r,a]:(Fe=n,n=i)):(Fe=n,n=i);var o;t=n!==i?e.substring(t,Fe):n;return t}())!==i){for(a=Fe,o=[],e.substr(Fe,2)===ye?(s=ye,Fe+=2):(s=i,0===je&&qe(be)),s===i&&(V.test(e.charAt(Fe))?(s=e.charAt(Fe),Fe++):(s=i,0===je&&qe(Z)));s!==i;)o.push(s),e.substr(Fe,2)===ye?(s=ye,Fe+=2):(s=i,0===je&&qe(be)),s===i&&(V.test(e.charAt(Fe))?(s=e.charAt(Fe),Fe++):(s=i,0===je&&qe(Z)));(a=o!==i?e.substring(a,Fe):o)!==i?(39===e.charCodeAt(Fe)?(o=B,Fe++):(o=i,0===je&&qe(M)),o===i&&(o=null),o!==i?(Te=t,t=n=r+a.replace("''","'")):(Fe=t,t=i)):(Fe=t,t=i)}else Fe=t,t=i;else Fe=t,t=i;return t}function ct(){var t,n,r,a,o;return t=Fe,n=Fe,e.length>Fe?(r=e.charAt(Fe),Fe++):(r=i,0===je&&qe(S)),r!==i?(Te=Fe,(a=(a=!("<"===(o=r)||"{"===o||vt()&&"#"===o||mt()&&"}"===o||mt()&&">"===o))?void 0:i)!==i?n=r=[r,a]:(Fe=n,n=i)):(Fe=n,n=i),n===i&&(10===e.charCodeAt(Fe)?(n="\n",Fe++):(n=i,0===je&&qe(Ae))),t=n!==i?e.substring(t,Fe):n}function pt(){var t,n;return je++,t=Fe,(n=ft())===i&&(n=dt()),t=n!==i?e.substring(t,Fe):n,je--,t===i&&(n=i,0===je&&qe(_e)),t}function ht(){var t,n;return je++,t=Fe,(n=ft())===i&&(n=function(){var t,n,r,a,o;je++,t=Fe,n=[],45===e.charCodeAt(Fe)?(r=ge,Fe++):(r=i,0===je&&qe(me));r===i&&(r=Fe,a=Fe,je++,(o=it())===i&&(o=at()),je--,o===i?a=void 0:(Fe=a,a=i),a!==i?(e.length>Fe?(o=e.charAt(Fe),Fe++):(o=i,0===je&&qe(S)),o!==i?r=a=[a,o]:(Fe=r,r=i)):(Fe=r,r=i));if(r!==i)for(;r!==i;)n.push(r),45===e.charCodeAt(Fe)?(r=ge,Fe++):(r=i,0===je&&qe(me)),r===i&&(r=Fe,a=Fe,je++,(o=it())===i&&(o=at()),je--,o===i?a=void 0:(Fe=a,a=i),a!==i?(e.length>Fe?(o=e.charAt(Fe),Fe++):(o=i,0===je&&qe(S)),o!==i?r=a=[a,o]:(Fe=r,r=i)):(Fe=r,r=i));else n=i;t=n!==i?e.substring(t,Fe):n;je--,t===i&&(n=i,0===je&&qe($e));return t}()),t=n!==i?e.substring(t,Fe):n,je--,t===i&&(n=i,0===je&&qe(we)),t}function ft(){var t,n,r,a,o;if(je++,t=Fe,48===e.charCodeAt(Fe)?(n="0",Fe++):(n=i,0===je&&qe(Ce)),n!==i&&(Te=t,n=0),(t=n)===i){if(t=Fe,n=Fe,ke.test(e.charAt(Fe))?(r=e.charAt(Fe),Fe++):(r=i,0===je&&qe(Ee)),r!==i){for(a=[],Oe.test(e.charAt(Fe))?(o=e.charAt(Fe),Fe++):(o=i,0===je&&qe(Se));o!==i;)a.push(o),Oe.test(e.charAt(Fe))?(o=e.charAt(Fe),Fe++):(o=i,0===je&&qe(Se));a!==i?n=r=[r,a]:(Fe=n,n=i)}else Fe=n,n=i;n!==i&&(Te=t,n=parseInt(n.join(""),10)),t=n}return je--,t===i&&(n=i,0===je&&qe(xe)),t}function dt(){var t,n,r,a,o;if(je++,t=Fe,n=[],r=Fe,a=Fe,je++,(o=it())===i&&(o=at()),je--,o===i?a=void 0:(Fe=a,a=i),a!==i?(e.length>Fe?(o=e.charAt(Fe),Fe++):(o=i,0===je&&qe(S)),o!==i?r=a=[a,o]:(Fe=r,r=i)):(Fe=r,r=i),r!==i)for(;r!==i;)n.push(r),r=Fe,a=Fe,je++,(o=it())===i&&(o=at()),je--,o===i?a=void 0:(Fe=a,a=i),a!==i?(e.length>Fe?(o=e.charAt(Fe),Fe++):(o=i,0===je&&qe(S)),o!==i?r=a=[a,o]:(Fe=r,r=i)):(Fe=r,r=i);else n=i;return t=n!==i?e.substring(t,Fe):n,je--,t===i&&(n=i,0===je&&qe(De)),t}var gt=["root"];function mt(){return gt.length>1}function vt(){return"plural"===gt[gt.length-1]}function yt(){return t&&t.captureLocation?{location:Le()}:{}}if((n=o())!==i&&Fe===e.length)return n;throw n!==i&&Fe<e.length&&qe({type:"end"}),He(Re,Ne<e.length?e.charAt(Ne):null,Ne<e.length?Ue(Ne,Ne+1):Ue(Ne,Ne))},_=function(){for(var e=0,t=0,n=arguments.length;t<n;t++)e+=arguments[t].length;var r=Array(e),i=0;for(t=0;t<n;t++)for(var a=arguments[t],o=0,s=a.length;o<s;o++,i++)r[i]=a[o];return r},w=/(^|[^\\])#/g;function x(e){e.forEach((function(e){(p(e)||c(e))&&Object.keys(e.options).forEach((function(t){for(var n,r=e.options[t],i=-1,o=void 0,s=0;s<r.value.length;s++){var l=r.value[s];if(a(l)&&w.test(l.value)){i=s,o=l;break}}if(o){var u=o.value.replace(w,"$1{"+e.value+", number}"),c=A(u);(n=r.value).splice.apply(n,_([i,1],c))}x(r.value)}))}))}function C(e,t){var n=A(e,t);return t&&!1===t.normalizeHashtagInPlural||x(n),n}var k=function(){for(var e=0,t=0,n=arguments.length;t<n;t++)e+=arguments[t].length;var r=Array(e),i=0;for(t=0;t<n;t++)for(var a=arguments[t],o=0,s=a.length;o<s;o++,i++)r[i]=a[o];return r};function E(e){return JSON.stringify(e.map((function(e){return e&&"object"==typeof e?(t=e,Object.keys(t).sort().map((function(e){var n;return(n={})[e]=t[e],n}))):e;var t})))}const O=function(e,t){return void 0===t&&(t={}),function(){for(var n,r=[],i=0;i<arguments.length;i++)r[i]=arguments[i];var a=E(r),o=a&&t[a];return o||(o=new((n=e).bind.apply(n,k([void 0],r))),a&&(t[a]=o)),o}};var S=function(){return(S=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)},D=/(?:[Eec]{1,6}|G{1,5}|[Qq]{1,5}|(?:[yYur]+|U{1,5})|[ML]{1,5}|d{1,2}|D{1,3}|F{1}|[abB]{1,5}|[hkHK]{1,2}|w{1,2}|W{1}|m{1,2}|s{1,2}|[zZOvVxX]{1,4})(?=([^']*'[^']*')*[^']*$)/g;function $(e){var t={};return e.replace(D,(function(e){var n=e.length;switch(e[0]){case"G":t.era=4===n?"long":5===n?"narrow":"short";break;case"y":t.year=2===n?"2-digit":"numeric";break;case"Y":case"u":case"U":case"r":throw new RangeError("`Y/u/U/r` (year) patterns are not supported, use `y` instead");case"q":case"Q":throw new RangeError("`q/Q` (quarter) patterns are not supported");case"M":case"L":t.month=["numeric","2-digit","short","long","narrow"][n-1];break;case"w":case"W":throw new RangeError("`w/W` (week) patterns are not supported");case"d":t.day=["numeric","2-digit"][n-1];break;case"D":case"F":case"g":throw new RangeError("`D/F/g` (day) patterns are not supported, use `d` instead");case"E":t.weekday=4===n?"short":5===n?"narrow":"short";break;case"e":if(n<4)throw new RangeError("`e..eee` (weekday) patterns are not supported");t.weekday=["short","long","narrow","short"][n-4];break;case"c":if(n<4)throw new RangeError("`c..ccc` (weekday) patterns are not supported");t.weekday=["short","long","narrow","short"][n-4];break;case"a":t.hour12=!0;break;case"b":case"B":throw new RangeError("`b/B` (period) patterns are not supported, use `a` instead");case"h":t.hourCycle="h12",t.hour=["numeric","2-digit"][n-1];break;case"H":t.hourCycle="h23",t.hour=["numeric","2-digit"][n-1];break;case"K":t.hourCycle="h11",t.hour=["numeric","2-digit"][n-1];break;case"k":t.hourCycle="h24",t.hour=["numeric","2-digit"][n-1];break;case"j":case"J":case"C":throw new RangeError("`j/J/C` (hour) patterns are not supported, use `h/H/K/k` instead");case"m":t.minute=["numeric","2-digit"][n-1];break;case"s":t.second=["numeric","2-digit"][n-1];break;case"S":case"A":throw new RangeError("`S/A` (second) pattenrs are not supported, use `s` instead");case"z":t.timeZoneName=n<4?"short":"long";break;case"Z":case"O":case"v":case"V":case"X":case"x":throw new RangeError("`Z/O/v/V/X/x` (timeZone) pattenrs are not supported, use `z` instead")}return""})),t}var F=/^\.(?:(0+)(\*)?|(#+)|(0+)(#+))$/g,T=/^(@+)?(\+|#+)?$/g;function I(e){var t={};return e.replace(T,(function(e,n,r){return"string"!=typeof r?(t.minimumSignificantDigits=n.length,t.maximumSignificantDigits=n.length):"+"===r?t.minimumSignificantDigits=n.length:"#"===n[0]?t.maximumSignificantDigits=n.length:(t.minimumSignificantDigits=n.length,t.maximumSignificantDigits=n.length+("string"==typeof r?r.length:0)),""})),t}function N(e){switch(e){case"sign-auto":return{signDisplay:"auto"};case"sign-accounting":return{currencySign:"accounting"};case"sign-always":return{signDisplay:"always"};case"sign-accounting-always":return{signDisplay:"always",currencySign:"accounting"};case"sign-except-zero":return{signDisplay:"exceptZero"};case"sign-accounting-except-zero":return{signDisplay:"exceptZero",currencySign:"accounting"};case"sign-never":return{signDisplay:"never"}}}function R(e){var t=N(e);return t||{}}function j(e){for(var t={},n=0,r=e;n<r.length;n++){var i=r[n];switch(i.stem){case"percent":t.style="percent";continue;case"currency":t.style="currency",t.currency=i.options[0];continue;case"group-off":t.useGrouping=!1;continue;case"precision-integer":case".":t.maximumFractionDigits=0;continue;case"measure-unit":t.style="unit",t.unit=i.options[0].replace(/^(.*?)-/,"");continue;case"compact-short":t.notation="compact",t.compactDisplay="short";continue;case"compact-long":t.notation="compact",t.compactDisplay="long";continue;case"scientific":t=S(S(S({},t),{notation:"scientific"}),i.options.reduce((function(e,t){return S(S({},e),R(t))}),{}));continue;case"engineering":t=S(S(S({},t),{notation:"engineering"}),i.options.reduce((function(e,t){return S(S({},e),R(t))}),{}));continue;case"notation-simple":t.notation="standard";continue;case"unit-width-narrow":t.currencyDisplay="narrowSymbol",t.unitDisplay="narrow";continue;case"unit-width-short":t.currencyDisplay="code",t.unitDisplay="short";continue;case"unit-width-full-name":t.currencyDisplay="name",t.unitDisplay="long";continue;case"unit-width-iso-code":t.currencyDisplay="symbol";continue}if(F.test(i.stem)){if(i.options.length>1)throw new RangeError("Fraction-precision stems only accept a single optional option");i.stem.replace(F,(function(e,n,r,i,a,o){return"*"===r?t.minimumFractionDigits=n.length:i&&"#"===i[0]?t.maximumFractionDigits=i.length:a&&o?(t.minimumFractionDigits=a.length,t.maximumFractionDigits=a.length+o.length):(t.minimumFractionDigits=n.length,t.maximumFractionDigits=n.length),""})),i.options.length&&(t=S(S({},t),I(i.options[0])))}else if(T.test(i.stem))t=S(S({},t),I(i.stem));else{var a=N(i.stem);a&&(t=S(S({},t),a))}}return t}var P,L=function(){var e=function(t,n){return(e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n])})(t,n)};return function(t,n){function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}}();!function(e){e.MISSING_VALUE="MISSING_VALUE",e.INVALID_VALUE="INVALID_VALUE",e.MISSING_INTL_API="MISSING_INTL_API"}(P||(P={}));var z,B=function(e){function t(t,n,r){var i=e.call(this,t)||this;return i.code=n,i.originalMessage=r,i}return L(t,e),t.prototype.toString=function(){return"[formatjs Error: "+this.code+"] "+this.message},t}(Error),M=function(e){function t(t,n,r,i){return e.call(this,'Invalid values for "'+t+'": "'+n+'". Options are "'+Object.keys(r).join('", "')+'"',"INVALID_VALUE",i)||this}return L(t,e),t}(B),V=function(e){function t(t,n,r){return e.call(this,'Value for "'+t+'" must be of type '+n,"INVALID_VALUE",r)||this}return L(t,e),t}(B),Z=function(e){function t(t,n){return e.call(this,'The intl string context variable "'+t+'" was not provided to the string "'+n+'"',"MISSING_VALUE",n)||this}return L(t,e),t}(B);function U(e){return"function"==typeof e}function q(e,t,n,r,i,m,v){if(1===e.length&&a(e[0]))return[{type:0,value:e[0].value}];for(var y=[],b=0,A=e;b<A.length;b++){var _=A[b];if(a(_))y.push({type:0,value:_.value});else if(h(_))"number"==typeof m&&y.push({type:0,value:n.getNumberFormat(t).format(m)});else{var w=_.value;if(!i||!(w in i))throw new Z(w,v);var x=i[w];if(o(_))x&&"string"!=typeof x&&"number"!=typeof x||(x="string"==typeof x||"number"==typeof x?String(x):""),y.push({type:"string"==typeof x?0:1,value:x});else if(l(_)){var C="string"==typeof _.style?r.date[_.style]:g(_.style)?$(_.style.pattern):void 0;y.push({type:0,value:n.getDateTimeFormat(t,C).format(x)})}else if(u(_)){C="string"==typeof _.style?r.time[_.style]:g(_.style)?$(_.style.pattern):void 0;y.push({type:0,value:n.getDateTimeFormat(t,C).format(x)})}else if(s(_)){C="string"==typeof _.style?r.number[_.style]:d(_.style)?j(_.style.tokens):void 0;y.push({type:0,value:n.getNumberFormat(t,C).format(x)})}else{if(f(_)){var k=_.children,E=_.value,O=i[E];if(!U(O))throw new V(E,"function",v);var S=q(k,t,n,r,i),D=O.apply(void 0,S.map((function(e){return e.value})));Array.isArray(D)||(D=[D]),y.push.apply(y,D.map((function(e){return{type:"string"==typeof e?0:1,value:e}})))}if(c(_)){if(!(F=_.options[x]||_.options.other))throw new M(_.value,x,Object.keys(_.options),v);y.push.apply(y,q(F.value,t,n,r,i))}else if(p(_)){var F;if(!(F=_.options["="+x])){if(!Intl.PluralRules)throw new B('Intl.PluralRules is not available in this environment.\nTry polyfilling it using "@formatjs/intl-pluralrules"\n',"MISSING_INTL_API",v);var T=n.getPluralRules(t,{type:_.pluralType}).select(x-(_.offset||0));F=_.options[T]||_.options.other}if(!F)throw new M(_.value,x,Object.keys(_.options),v);y.push.apply(y,q(F.value,t,n,r,i,x-(_.offset||0)))}else;}}}return function(e){return e.length<2?e:e.reduce((function(e,t){var n=e[e.length-1];return n&&0===n.type&&0===t.type?n.value+=t.value:e.push(t),e}),[])}(y)}!function(e){e[e.literal=0]="literal",e[e.object=1]="object"}(z||(z={}));var H=function(){return(H=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};function G(e,t){return t?Object.keys(e).reduce((function(n,r){var i,a;return n[r]=(i=e[r],(a=t[r])?H(H(H({},i||{}),a||{}),Object.keys(i).reduce((function(e,t){return e[t]=H(H({},i[t]),a[t]||{}),e}),{})):i),n}),H({},e)):e}const K=function(){function e(t,n,r,i){var a,o=this;if(void 0===n&&(n=e.defaultLocale),this.formatterCache={number:{},dateTime:{},pluralRules:{}},this.format=function(e){var t=o.formatToParts(e);if(1===t.length)return t[0].value;var n=t.reduce((function(e,t){return e.length&&0===t.type&&"string"==typeof e[e.length-1]?e[e.length-1]+=t.value:e.push(t.value),e}),[]);return n.length<=1?n[0]||"":n},this.formatToParts=function(e){return q(o.ast,o.locales,o.formatters,o.formats,e,void 0,o.message)},this.resolvedOptions=function(){return{locale:Intl.NumberFormat.supportedLocalesOf(o.locales)[0]}},this.getAst=function(){return o.ast},"string"==typeof t){if(this.message=t,!e.__parse)throw new TypeError("IntlMessageFormat.__parse must be set to process `message` of type `string`");this.ast=e.__parse(t,{normalizeHashtagInPlural:!1})}else this.ast=t;if(!Array.isArray(this.ast))throw new TypeError("A message must be provided as a String or AST.");this.formats=G(e.formats,r),this.locales=n,this.formatters=i&&i.formatters||(void 0===(a=this.formatterCache)&&(a={number:{},dateTime:{},pluralRules:{}}),{getNumberFormat:O(Intl.NumberFormat,a.number),getDateTimeFormat:O(Intl.DateTimeFormat,a.dateTime),getPluralRules:O(Intl.PluralRules,a.pluralRules)})}return Object.defineProperty(e,"defaultLocale",{get:function(){return e.memoizedDefaultLocale||(e.memoizedDefaultLocale=(new Intl.NumberFormat).resolvedOptions().locale),e.memoizedDefaultLocale},enumerable:!0,configurable:!0}),e.memoizedDefaultLocale=null,e.__parse=C,e.formats={number:{currency:{style:"currency"},percent:{style:"percent"}},date:{short:{month:"numeric",day:"numeric",year:"2-digit"},medium:{month:"short",day:"numeric",year:"numeric"},long:{month:"long",day:"numeric",year:"numeric"},full:{weekday:"long",month:"long",day:"numeric",year:"numeric"}},time:{short:{hour:"numeric",minute:"numeric"},medium:{hour:"numeric",minute:"numeric",second:"numeric"},long:{hour:"numeric",minute:"numeric",second:"numeric",timeZoneName:"short"},full:{hour:"numeric",minute:"numeric",second:"numeric",timeZoneName:"short"}}},e}()}}]);
//# sourceMappingURL=chunk.6333adc5b0561e1ac161.js.map